'use strict';

const ah = require('async_hooks');

const {
  logger
} = require('./logger');

const {
  conditionalRequire
} = require('./utils');

if ((ah === null || ah === void 0 ? void 0 : ah.createHook) !== undefined) {
  const originalCreateHook = ah.createHook.bind(ah);

  function patchTracer() {
    try {
      logger.debug("Hooking async_hooks' `createHook`"); // Change `createHook` to what we want it to be

      ah.createHook = hook => {
        let originalBefore = hook.before;

        if (typeof originalBefore === "function") {
          originalBefore = originalBefore.bind(hook);
        }

        hook.before = asyncId => {
          try {
            if (module.exports.tracerInitialized) {
              const span = global.__getSpan();

              if (span != null && span.span != null) {
                global.__currentSpan = span.span;
              }
            }
          } catch (e) {
            logger.debug("hook.before failed with:", e);
          }

          if (typeof originalBefore === "function") {
            originalBefore(asyncId);
          }
        };

        hook.before = hook.before.bind(hook);
        return originalCreateHook(hook);
      };

      ah.createHook = ah.createHook.bind(ah);
      const dd = conditionalRequire('dd-trace');
      const ddCore = conditionalRequire('dd-trace/packages/datadog-core');

      if (dd == null || ddCore == null || typeof dd.init !== "function") {
        ah.createHook = originalCreateHook;
        return false;
      }

      global.__getSpan = () => {
        if (ddCore.storage == null || typeof ddCore.storage.getStore !== "function") {
          return null;
        }

        return ddCore.storage.getStore();
      }; // Return `createHook` to what it was


      ah.createHook = originalCreateHook;
      const originalTracerInit = dd.init.bind(dd);

      dd.init = opts => {
        const tracer = originalTracerInit(opts);
        module.exports.tracerInitialized = true;
        return tracer;
      };

      dd.init = dd.init.bind(dd);
      return true;
    } catch (e) {
      ah.createHook = originalCreateHook;
      logger.error("Failed to hook dd's async hook", e);
      return false;
    }
  }

  module.exports = {
    patchTracer: patchTracer,
    tracerInitialized: false
  };
}