"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ConfigUpdater = void 0;

var _logger = require("./logger");

const config = require('./config');

const nodeSupport = require('./nodeSupport');

const trueValues = ['y', 'Y', 'yes', 'Yes', 'YES', 'true', 'True', 'TRUE', '1', true];

class ConfigUpdater {
  static updateConfig(newConfig, configObject) {
    const prefix = config.FrontendConfig.ENABLED ? 'BROWSER_' : 'NODE_';
    newConfig.forEach(function (v, k) {
      switch (k) {
        case prefix + "StringCache_UserMessage":
          _logger.logger.debug("Updating STRING_CACHE_USERMESSAGE value to: " + (trueValues.indexOf(v) !== -1));

          configObject.DumpConfig.STRING_CACHE_USERMESSAGE = trueValues.indexOf(v) !== -1;
          break;

        case prefix + "PROTOBUF_VERSION_2":
          let protobuf2EnvVar = process.env.PROTOBUF_VERSION_2;

          if (protobuf2EnvVar) {
            _logger.logger.debug("Updating Protobuf_Version2 from env var value to: " + (trueValues.indexOf(protobuf2EnvVar) !== -1));

            configObject.OutputWsConfiguration.PROTOBUF_VERSION2 = trueValues.indexOf(protobuf2EnvVar) !== -1;
          } else {
            _logger.logger.debug("Updating Protobuf_Version2 value to: " + (trueValues.indexOf(v) !== -1));

            configObject.OutputWsConfiguration.PROTOBUF_VERSION2 = trueValues.indexOf(v) !== -1;
          }

          break;

        case prefix + "GLOBAL_RATE_LIMIT_QUOTA_MS":
          if (configObject.RateLimitConfiguration.GLOBAL_RATE_LIMIT === "") {
            configObject.RateLimitConfiguration.GLOBAL_RATE_LIMIT_QUOTA_MS = v;

            if (configObject.RateLimitConfiguration.GLOBAL_RATE_LIMIT_WINDOW_SIZE_MS !== "") {
              configObject.RateLimitConfiguration.GLOBAL_RATE_LIMIT = configObject.RateLimitConfiguration.GLOBAL_RATE_LIMIT_QUOTA_MS + "/" + configObject.RateLimitConfiguration.GLOBAL_RATE_LIMIT_WINDOW_SIZE_MS;

              _logger.logger.debug(`Updating GLOBAL_RATE_LIMIT_SPECS value to: ${configObject.RateLimitConfiguration.GLOBAL_RATE_LIMIT}`);
            }
          } else {
            _logger.logger.debug(`Global rate limit specs already set to: ${configObject.RateLimitConfiguration.GLOBAL_RATE_LIMIT}`);
          }

          break;

        case prefix + "GLOBAL_RATE_LIMIT_WINDOW_SIZE_MS":
          if (configObject.RateLimitConfiguration.GLOBAL_RATE_LIMIT === "") {
            configObject.RateLimitConfiguration.GLOBAL_RATE_LIMIT_WINDOW_SIZE_MS = v;

            if (configObject.RateLimitConfiguration.GLOBAL_RATE_LIMIT_QUOTA_MS !== "") {
              configObject.RateLimitConfiguration.GLOBAL_RATE_LIMIT = configObject.RateLimitConfiguration.GLOBAL_RATE_LIMIT_QUOTA_MS + "/" + configObject.RateLimitConfiguration.GLOBAL_RATE_LIMIT_WINDOW_SIZE_MS;

              _logger.logger.debug(`Updating GLOBAL_RATE_LIMIT_SPECS value to: ${configObject.RateLimitConfiguration.GLOBAL_RATE_LIMIT}`);
            }
          }

          break;

        case prefix + "SDK_SUPPORTED_VERSIONS":
          if (!config.AgentComConfiguration.SKIP_NODE_VERSION_VERIFICATION) {
            nodeSupport.updateVersionSupport(v);

            _logger.logger.debug(`Updating DebuggerService.IS_SUPPORTED value to: ${config.DebuggerService.IS_SUPPORTED}`);
          }

          break;
      }
    });
  }

}

exports.ConfigUpdater = ConfigUpdater;